@@ -5,18 +5,20 @@
 #' @seealso GetPackageGraphs
 #' @param pkg_name (string) name of a package
 #' @param pkg_reporters (list) a list of package reporters
-#' @param pkg_path (string) The path to the package repository.  
-#'                     If given, coverage will be calculated for each function.
+#' @param pkg_path (string) The path to the package repository. If given, coverage
+#'                 will be calculated for each function. \code{pkg_path} can be an
+#'                 absolute or relative path.
 #' @param report_path (string) The path and filename of the output report.  Default
 #'                   report will be produced in working directory.
 #' @importFrom assertthat assert_that is.string
 #' @importFrom methods is
+#' @importFrom utils browseURL
 #' @return A list of instantiated pkg_reporters fitted to \code{pkg_name}
 #' @export
 CreatePackageReport <- function(pkg_name
                                 , pkg_reporters = DefaultReporters()
                                 , pkg_path = NULL
-                                , report_path = file.path(getwd(), paste0(pkg_name, "_report.html"))
+                                , report_path = tempfile(pattern = pkg_name, fileext = ".html")
                                 ) {
     # Input checks
     assertthat::assert_that(
@@ -50,6 +52,8 @@ CreatePackageReport <- function(pkg_name
       , pkg_name = pkg_name
     )
     
+    utils::browseURL(report_path)
+    
     return(invisible(builtReporters))
 }
 
